@@ -63,9 +63,9 @@
 
 #include <libxml/xmlsave.h>
 
-const char* const flickcurl_short_copyright_string = "Copyright 2007-2013 David Beckett.";
+const char* const flickcurl_short_copyright_string = "Copyright 2007-2014 David Beckett.";
 
-const char* const flickcurl_copyright_string = "Copyright (C) 2007-2013 David Beckett - http://www.dajobe.org/";
+const char* const flickcurl_copyright_string = "Copyright (C) 2007-2014 David Beckett - http://www.dajobe.org/";
 
 const char* const flickcurl_license_string = "LGPL 2.1 or newer, GPL 2 or newer, Apache 2.0 or newer.\nSee http://librdf.org/flickcurl/ for full terms.";
 
@@ -73,12 +73,12 @@ const char* const flickcurl_home_url_string = "http://librdf.org/flickcurl/";
 const char* const flickcurl_version_string = VERSION;
 
 
-const char* const flickcurl_flickr_service_uri =  "http://www.flickr.com/services/rest/";
-const char* const flickcurl_flickr_upload_service_uri =  "http://api.flickr.com/services/upload/";
-const char* const flickcurl_flickr_replace_service_uri =  "http://api.flickr.com/services/replace/";
-const char* const flickcurl_flickr_oauth_request_token_uri =  "http://www.flickr.com/services/oauth/request_token";
-const char* const flickcurl_flickr_oauth_authorize_uri =  "http://www.flickr.com/services/oauth/authorize";
-const char* const flickcurl_flickr_oauth_access_token_uri =  "http://www.flickr.com/services/oauth/access_token";
+const char* const flickcurl_flickr_service_uri =  "https://api.flickr.com/services/rest/";
+const char* const flickcurl_flickr_upload_service_uri =  "https://up.flickr.com/services/upload/";
+const char* const flickcurl_flickr_replace_service_uri =  "https://up.flickr.com/services/replace/";
+const char* const flickcurl_flickr_oauth_request_token_uri =  "https://www.flickr.com/services/oauth/request_token";
+const char* const flickcurl_flickr_oauth_authorize_uri =  "https://www.flickr.com/services/oauth/authorize";
+const char* const flickcurl_flickr_oauth_access_token_uri =  "https://www.flickr.com/services/oauth/access_token";
 
 
 static void
@@ -1529,23 +1529,38 @@ flickcurl_free_form(char **form, int count)
 }
 
 
+/*
+* flickcurl_invoke_get_form_content:
+* @fc: flickcurl object
+* @count_p: pointer to store count (or NULL)
+*
+* INTERNAL - decoded content from current request as HTTP FORM and return fields
+*
+* NOTE: The result may be an empty array with just two NULL
+* terminating pointers if there are no fields.
+*
+* Return value: array of [char* field name, char* field value] with
+* NULL pair terminating or NULL on failure
+*/
 char**
 flickcurl_invoke_get_form_content(flickcurl *fc, int* count_p)
 {
   char* content = NULL;
   char** form = NULL;
   char *p;
-  int count;
+  int count = 0;
   int i;
 
   if(flickcurl_invoke_common(fc, &content, NULL, NULL))
     return NULL;
 
-  for(p = content, count = 0; *p; p++) {
-    if(*p == '&')
-      count++;
+  if(content) {
+    for(p = content; *p; p++) {
+      if(*p == '&')
+        count++;
+    }
+    count++; /* counting separators so need +1 for number of contents */
   }
-  count++; /* counting separators so need +1 for number of contents */
   
   /* Allocate count + 1 sized array of char* (key, value) pointers
    * The last pair are always (NULL, NULL).
@@ -1554,37 +1569,35 @@ flickcurl_invoke_get_form_content(flickcurl *fc, int* count_p)
    * and owned by this array and stored in form[0].
    */
   form = (char**)calloc(2*(count + 1), sizeof(char*));
-  if(!form)
-    goto tidy;
-
-  for(p = content, i = 0; *p; p++) {
-    char *start = p;
-    
-    while(*p && *p != '&' && *p != '=')
-      p++;
-
-    form[i++] = start;
-
-    if(!*p)
-      break;
-    *p = '\0';
+  if(!form) {
+    if(content)
+      free(content);
+    return NULL;
   }
-  form[i++] = '\0';
-  form[i] = '\0';
-  
+
+  if(content) {
+    for(p = content, i = 0; *p; p++) {
+      char *start = p;
+
+      while(*p && *p != '&' && *p != '=')
+        p++;
+
+      form[i++] = start;
+
+      if(!*p)
+        break;
+      *p = '\0';
+    }
+    form[i++] = NULL;
+    form[i] = NULL;
+
+    free(content);
+  }
+
   if(count_p)
     *count_p = count;
 
   return form;
-
-  tidy:
-  if(form)
-    free(form);
-
-  if(content)
-    free(content);
-  
-  return NULL;
 }
 
 
@@ -1619,8 +1632,8 @@ flickcurl_unixtime_to_sqltimestamp(time_t unix_time)
   char *value = NULL;
   
   structured_time = (struct tm*)gmtime(&unix_time);
-  len = ISO_DATE_LEN;
-  strftime(date_buffer, len+1, SQL_DATETIME_FORMAT, structured_time);
+  len = SQL_DATETIME_LEN;
+  strftime(date_buffer, sizeof(date_buffer), SQL_DATETIME_FORMAT, structured_time);
   
   value = (char*)malloc(len + 1);
   memcpy(value, date_buffer, len + 1);
@@ -2282,7 +2295,7 @@ flickcurl_append_photos_list_params(flickcurl* fc,
 
 
 
-#define EXTRAS_FORMAT_COUNT 19
+#define EXTRAS_FORMAT_COUNT 22
 static struct {
   const char* name;
   const char* label;
@@ -2304,14 +2317,19 @@ flickcurl_extras_format_info[EXTRAS_FORMAT_COUNT+1] = {
   { "path_alias", "Path alias for owner like /photos/USERNAME"},
 
   { "tags", "Item clean tags (safe for HTML, URLs)"},
-  /* http://tech.groups.yahoo.com/group/yws-flickr/message/5053 */
-  { "url_m", "URL of medium size image"},
+
+  /* https://www.flickr.com/services/api/misc.urls.html */
+  { "url_c", "URL of medium 800, 800 on longest size image"},
+  { "url_m", "URL of small, medium size image"},
+  { "url_n", "URL of small, 320 on longest side size image"},
   { "url_o", "URL of original size image"},
-  { "url_s", "URL of small size image"},
+  { "url_q", "URL of large square 150x150 size image"},
+  { "url_s", "URL of small suqare 75x75 size image"},
   { "url_sq", "URL of square size image"},
-  { "url_t", "URL of thumbnail size image"},
+  { "url_t", "URL of thumbnail, 100 on longest side size image"},
 
   { "views", "Number of times item has been viewed"},
+
   { NULL, NULL }
 };
 
