@@ -56,9 +56,7 @@ flickcurl_galleries_addPhoto(flickcurl* fc, const char* gallery_id,
                              const char* photo_id, const char* comment_text)
 {
   xmlDocPtr doc = NULL;
-  xmlXPathContextPtr xpathCtx = NULL; 
-  void* result = NULL;
-  
+
   flickcurl_init_params(fc, 1);
 
   if(!gallery_id || !photo_id)
@@ -79,24 +77,9 @@ flickcurl_galleries_addPhoto(flickcurl* fc, const char* gallery_id,
   if(!doc)
     goto tidy;
 
-
-  xpathCtx = xmlXPathNewContext(doc);
-  if(!xpathCtx) {
-    flickcurl_error(fc, "Failed to create XPath context for document");
-    fc->failed = 1;
-    goto tidy;
-  }
-
-  result = NULL; /* your code here */
-
   tidy:
-  if(xpathCtx)
-    xmlXPathFreeContext(xpathCtx);
 
-  if(fc->failed)
-    result = NULL;
-
-  return (result == NULL);
+  return fc->failed;
 }
 
 
@@ -166,8 +149,11 @@ flickcurl_galleries_create(flickcurl* fc,
   if(xpathCtx)
     xmlXPathFreeContext(xpathCtx);
 
-  if(fc->failed)
+  if(fc->failed) {
+    if(gallery_id)
+      free(gallery_id);
     gallery_id = NULL;
+  }
 
   return gallery_id;
 }
@@ -467,8 +453,11 @@ flickcurl_galleries_getList(flickcurl* fc, const char* user_id,
   if(xpathCtx)
     xmlXPathFreeContext(xpathCtx);
 
-  if(fc->failed)
+  if(fc->failed) {
+    if(galleries)
+      flickcurl_free_galleries(galleries);
     galleries = NULL;
+  }
 
   return galleries;
 }
@@ -540,8 +529,11 @@ flickcurl_galleries_getListForPhoto(flickcurl* fc, const char* photo_id,
   if(xpathCtx)
     xmlXPathFreeContext(xpathCtx);
 
-  if(fc->failed)
+  if(fc->failed) {
+    if(galleries)
+      flickcurl_free_galleries(galleries);
     galleries = NULL;
+  }
 
   return galleries;
 }
