@@ -82,12 +82,9 @@ flickcurl_build_location(flickcurl* fc, xmlXPathContextPtr xpathCtx,
     xmlNodePtr node = nodes->nodeTab[i];
     xmlAttr* attr;
     
-    if(node->type != XML_ELEMENT_NODE) {
-      flickcurl_error(fc, "Got unexpected node type %d", node->type);
-      fc->failed = 1;
-      break;
-    }
-    
+    if(node->type != XML_ELEMENT_NODE)
+      continue;
+
     location = (flickcurl_location*)calloc(sizeof(flickcurl_location), 1);
     
     for(attr = node->properties; attr; attr = attr->next) {
@@ -114,7 +111,7 @@ flickcurl_build_location(flickcurl* fc, xmlXPathContextPtr xpathCtx,
             location->latitude, location->longitude, location->accuracy);
 #endif
 
-    /* Handle only first perm */
+    /* Handle only first location */
     break;
   } /* for nodes */
 
