@@ -212,15 +212,15 @@ flickcurl_oauth_build_key(flickcurl_oauth_data* od)
     return 1;
   
   p = od->key;
-  if(od->client_secret_len) {
+  if(od->client_secret && od->client_secret_len) {
     memcpy(p, od->client_secret, od->client_secret_len);
     p += od->client_secret_len;
   }
   *p++ = '&';
-  if(od->request_token_secret_len) {
+  if(od->request_token_secret && od->request_token_secret_len) {
     memcpy(p, od->request_token_secret, od->request_token_secret_len);
     p += od->request_token_secret_len;
-  } else if(od->token_secret_len) {
+  } else if(od->token_secret && od->token_secret_len) {
     memcpy(p, od->token_secret, od->token_secret_len);
     p += od->token_secret_len;
   }
@@ -294,7 +294,7 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   char* nonce = NULL;
   int free_nonce = 0;
   char* timestamp = NULL;
-  int rc = 0;
+  int rc = 1;
   int is_oauth_method = 0;
   char *p;
 
@@ -336,6 +336,9 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   if(method) { 
     size_t len = strlen(method);
     fc->method = (char*)malloc(len + 1);
+    if(!fc->method)
+      goto tidy;
+
     memcpy(fc->method, method, len + 1);
     is_oauth_method = !strncmp(method, "flickr.oauth.", 13);
   } else
@@ -366,6 +369,9 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   nonce = (char*)od->nonce;
   if(!nonce) {
     nonce = (char*)malloc(20);
+    if(!nonce)
+      goto tidy;
+
     free_nonce = 1;
     sprintf(nonce, "%ld", mtwist_u32rand(fc->mt));
   }
@@ -375,6 +381,9 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   flickcurl_add_param(fc, "oauth_signature_method", "HMAC-SHA1");
 
   timestamp = (char*)malloc(20);
+  if(!timestamp)
+    goto tidy;
+
   if(od->timestamp)
     sprintf(timestamp, "%ld", (long)od->timestamp);
   else {
@@ -398,8 +407,16 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
 
   /* +FLICKCURL_FLICKCURL_MAX_OAUTH_PARAM_COUNT for oauth fields +1 for NULL terminating pointer */
   fc->param_fields = (char**)calloc(fc->count + FLICKCURL_MAX_OAUTH_PARAM_COUNT + 1, sizeof(char*));
+  if(!fc->param_fields)
+    goto tidy;
+
   fc->param_values = (char**)calloc(fc->count + FLICKCURL_MAX_OAUTH_PARAM_COUNT + 1, sizeof(char*));
+  if(!fc->param_values)
+    goto tidy;
+
   values_len       = (size_t*)calloc(fc->count + FLICKCURL_MAX_OAUTH_PARAM_COUNT + 1, sizeof(size_t));
+  if(!values_len)
+    goto tidy;
 
   if((need_auth && (od->client_secret || od->token_secret)) || fc->sign)
     flickcurl_sort_args(fc);
@@ -422,9 +439,15 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
       fc->parameters[i][1] = "";
     }
     fc->param_fields[i] = (char*)malloc(param_len + 1);
+    if(!fc->param_fields[i])
+      goto tidy;
+
     memcpy(fc->param_fields[i], fc->parameters[i][0], param_len + 1);
 
     fc->param_values[i] = (char*)malloc(values_len[i] + 1);
+    if(!fc->param_values[i])
+      goto tidy;
+
     memcpy(fc->param_values[i], fc->parameters[i][1], values_len[i] + 1);
 
     /* 3x value len is conservative URI %XX escaping on every char */
@@ -434,10 +457,16 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   if(upload_field) {
     size_t len = strlen(upload_field);
     fc->upload_field = (char*)malloc(len + 1);
+    if(!fc->upload_field)
+      goto tidy;
+
     memcpy(fc->upload_field, upload_field, len + 1);
 
     len = strlen(upload_value);
     fc->upload_value = (char*)malloc(len + 1);
+    if(!fc->upload_value)
+      goto tidy;
+
     memcpy(fc->upload_value, upload_value, len + 1);
   }
 
@@ -457,6 +486,9 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
     for(i = 0; fc->parameters[i][0]; i++)
       param_buf_len += strlen(fc->parameters[i][0]) + 3 + (3 * values_len[i]) + 3;
     param_buf = (char*)malloc(param_buf_len + 1);
+    if(!param_buf)
+      goto tidy;
+
     *param_buf = '\0';
     
     p = param_buf;
@@ -488,6 +520,10 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
     buf_len += param_buf_len * 3;
 
     buf = (char*)malloc(buf_len + 1);
+    if(!buf) {
+      free(param_buf);
+      goto tidy;
+    }
 
     p = buf;
     memcpy(p, http_method, http_method_len);
@@ -516,7 +552,7 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
 #ifdef FLICKCURL_DEBUG
       fprintf(stderr, "flickcurl_oauth_build_key() failed\n");
 #endif
-      rc = 1;
+      free(buf);
       goto tidy;
     }
 
@@ -541,9 +577,15 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
     values_len[fc->count] = vlen;
     /* 15 = strlen(oauth_signature) */
     fc->param_fields[fc->count] = (char*)malloc(15 + 1);
+    if(!fc->param_fields[fc->count])
+      goto tidy;
+
     memcpy(fc->param_fields[fc->count], fc->parameters[fc->count][0], 15 + 1);
 
     fc->param_values[fc->count] = (char*)malloc(vlen + 1);
+    if(!fc->param_values[fc->count])
+      goto tidy;
+
     memcpy(fc->param_values[fc->count], fc->parameters[fc->count][1], vlen + 1);
 
     full_uri_len += 15 /* "oauth_signature" */ + 1 /* = */ + vlen;
@@ -568,6 +610,8 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   if(fc->uri_len < full_uri_len) {
     free(fc->uri);
     fc->uri = (char*)malloc(full_uri_len + 1);
+    if(!fc->uri)
+      goto tidy;
     fc->uri_len = full_uri_len;
   }
   /* fc_uri_len is strlen(service_uri) at this point */
@@ -615,6 +659,8 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   } while(0);
 #endif
 
+  rc = 0;
+
   tidy:
   if(signature_string)
     free(signature_string);
@@ -622,7 +668,7 @@ flickcurl_oauth_prepare_common(flickcurl *fc,
   if(values_len)
     free(values_len);
 
-  if(nonce && free_nonce)
+  if(free_nonce)
     free(nonce);
 
   if(timestamp)
@@ -1219,7 +1265,7 @@ static const char* test_token_secret  = NULL;
 
 /* Test DATA fields */
 static const char* test_http_request_method = "GET";
-static const char* test_uri_base_string     = "http://www.flickr.com/services/oauth/request_token";
+static const char* test_uri_base_string     = "https://www.flickr.com/services/oauth/request_token";
 static const char* test_oauth_callback_url  = "http://www.example.com";
 static const char* test_oauth_consumer_key  = "653e7a6ecc1d528c516cc8f92cf98611";
 static const char* test_oauth_nonce         = "95613465";
@@ -1233,10 +1279,10 @@ static const char* expected_key =
       "&";
 static const char* expected_data =
       "GET" "&"
-      "http%3A%2F%2Fwww.flickr.com%2Fservices%2Foauth%2Frequest_token" "&"
+      "https%3A%2F%2Fwww.flickr.com%2Fservices%2Foauth%2Frequest_token" "&"
       "oauth_callback%3Dhttp%253A%252F%252Fwww.example.com%26oauth_consumer_key%3D653e7a6ecc1d528c516cc8f92cf98611%26oauth_nonce%3D95613465%26oauth_signature_method%3DHMAC-SHA1%26oauth_timestamp%3D1305586162%26oauth_version%3D1.0";
 
-static const char* expected_signature = "7w18YS2bONDPL%2FzgyzP5XTr5af4%3D";
+static const char* expected_signature = "2zL7aYEzEEY0IvEgQjT7IqB518U%3D";
 
 static const char* program;
 
