@@ -167,36 +167,36 @@ flickcurl_free_photo(flickcurl_photo *photo)
  * Get a photo's image source URIs
  *
  * @c can be s,m,t,b for sizes, o for original, otherwise default
- * http://www.flickr.com/services/api/misc.urls.html
+ * https://www.flickr.com/services/api/misc.urls.html
  *
  * Return value: new source URI string or NULL on failure
  */
 char*
 flickcurl_photo_as_source_uri(flickcurl_photo *photo, const char c)
 {
-  char buf[1024];
+  char buf[512];
   char *result;
   size_t len;
   
   if(c == 'o') {
-    /* http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{o-secret}_o.(jpg|gif|png) */
-    sprintf(buf, "http://farm%s.static.flickr.com/%s/%s_%s_o.%s", 
+    /* https://farm{farm-id}.staticflickr.com/{server-id}/{id}_{o-secret}_o.(jpg|gif|png) */
+    sprintf(buf, "https://farm%s.staticflickr.com/%s/%s_%s_o.%s",
             photo->fields[PHOTO_FIELD_farm].string,
             photo->fields[PHOTO_FIELD_server].string,
             photo->id,
             photo->fields[PHOTO_FIELD_originalsecret].string,
             photo->fields[PHOTO_FIELD_originalformat].string);
   } else if (c == 'm' || c == 's' || c == 't' || c == 'b') {
-    /* http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{secret}_[mstb].jpg */
-    sprintf(buf, "http://farm%s.static.flickr.com/%s/%s_%s_%c.jpg",
+    /* https://farm{farm-id}.staticflickr.com/{server-id}/{id}_{secret}_[mstb].jpg */
+    sprintf(buf, "https://farm%s.staticflickr.com/%s/%s_%s_%c.jpg",
             photo->fields[PHOTO_FIELD_farm].string,
             photo->fields[PHOTO_FIELD_server].string,
             photo->id,
             photo->fields[PHOTO_FIELD_secret].string,
             c);
   } else {
-    /* http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{secret}.jpg */
-    sprintf(buf, "http://farm%s.static.flickr.com/%s/%s_%s.jpg",
+    /* https://farm{farm-id}.staticflickr.com/{server-id}/{id}_{secret}.jpg */
+    sprintf(buf, "https://farm%s.staticflickr.com/%s/%s_%s.jpg",
             photo->fields[PHOTO_FIELD_farm].string,
             photo->fields[PHOTO_FIELD_server].string,
             photo->id,
@@ -220,12 +220,12 @@ flickcurl_photo_as_source_uri(flickcurl_photo *photo, const char c)
 char*
 flickcurl_photo_as_page_uri(flickcurl_photo *photo)
 {
-  char buf[1024];
+  char buf[512];
   char *result;
   size_t len;
   
-  /* http://www.flickr.com/photos/{owner}/{photo id}/ */
-  sprintf(buf, "http://www.flickr.com/photos/%s/%s", 
+  /* https://www.flickr.com/photos/{owner}/{photo id}/ */
+  sprintf(buf, "https://www.flickr.com/photos/%s/%s",
           photo->fields[PHOTO_FIELD_owner_nsid].string, photo->id);
 
   len = strlen(buf);
@@ -319,6 +319,8 @@ flickcurl_photo_as_short_uri(flickcurl_photo *photo)
 static const char source_uri_match1[SOURCE_URI_MATCH1_LENGTH+1] = "http://farm";
 #define SOURCE_URI_MATCH2_LENGTH 19
 static const char source_uri_match2[SOURCE_URI_MATCH2_LENGTH+1] = ".static.flickr.com/";
+#define SOURCE_URI_MATCH3_LENGTH 18
+static const char source_uri_match3[SOURCE_URI_MATCH3_LENGTH+1] = ".staticflickr.com/";
 
 /**
  * flickcurl_source_uri_as_photo_id:
@@ -328,9 +330,10 @@ static const char source_uri_match2[SOURCE_URI_MATCH2_LENGTH+1] = ".static.flick
  *
  * Turns an URL that points to the photo into a photo ID.
  * i.e. given an URI like these:
- * <code>http://farm{farm-id}.static.flickr.com/{server-id}/{photo-id}_{o-secret}_o.(jpg|gif|png)</code> or
- * <code>http://farm{farm-id}.static.flickr.com/{server-id}/{photo-id}_{secret}_[mstb].jpg</code>
- * <code>http://farm{farm-id}.static.flickr.com/{server-id}/{photo-id}_{secret}.jpg</code>
+ * <code>https://farm{farm-id}.static.flickr.com/{server-id}/{photo-id}_{o-secret}_o.(jpg|gif|png)</code> or
+ * <code>https://farm{farm-id}.static.flickr.com/{server-id}/{photo-id}_{secret}_[mstb].jpg</code>
+ * <code>https://farm{farm-id}.static.flickr.com/{server-id}/{photo-id}_{secret}.jpg</code>
+ * (or the same with staticflickr.com)
  * returns the {photo-id}
  *
  * Return value: new photo ID string or NULL on failure
@@ -354,9 +357,13 @@ flickcurl_source_uri_as_photo_id(const char *uri)
   while(isdigit(*p))
     p++;
 
-  if(memcmp(p, source_uri_match2, SOURCE_URI_MATCH2_LENGTH))
-    return NULL;
-  p+= SOURCE_URI_MATCH2_LENGTH;
+  if(memcmp(p, source_uri_match2, SOURCE_URI_MATCH2_LENGTH)) {
+    if(memcmp(p, source_uri_match3, SOURCE_URI_MATCH3_LENGTH))
+      return NULL;
+    p+= SOURCE_URI_MATCH3_LENGTH;
+  } else {
+    p+= SOURCE_URI_MATCH2_LENGTH;
+  }
 
   /* now at {server-id}/{photo_id}_... */
   while(isdigit(*p))
@@ -394,22 +401,22 @@ flickcurl_source_uri_as_photo_id(const char *uri)
  * The icon URI returned is always a 48x48 pixel JPEG.
  *
  * If @server is 0 (or the other fields are NULL), the default icon URI of
- * http://www.flickr.com/images/buddyicon.jpg is returned.
+ * https://www.flickr.com/images/buddyicon.jpg is returned.
  *
- * Defined by http://www.flickr.com/services/api/misc.buddyicons.html
+ * Defined by https://www.flickr.com/services/api/misc.buddyicons.html
  *
  * Return value: new icon URI string or NULL on failure
  */
 char*
 flickcurl_user_icon_uri(int farm, int server, char *nsid)
 {
-  char buf[1024];
+  char buf[512];
   char *result;
   
   if(server && farm && nsid) {
     size_t len;
-    /* http://farm{icon-farm}.static.flickr.com/{icon-server}/buddyicons/{nsid}.jpg */
-    sprintf(buf, "http://farm%d.static.flickr.com/%d/buddicons/%s.jpg", 
+    /* https://farm{icon-farm}.staticflickr.com/{icon-server}/buddyicons/{nsid}.jpg */
+    sprintf(buf, "https://farm%d.staticflickr.com/%d/buddyicons/%s.jpg",
             farm, server, nsid); 
     len = strlen(buf);
     result = (char*)malloc(len + 1);
@@ -417,7 +424,7 @@ flickcurl_user_icon_uri(int farm, int server, char *nsid)
   } else {
     #define MAGIC_LEN 42
     result = (char*)malloc(MAGIC_LEN + 1);
-    memcpy(result, "http://www.flickr.com/images/buddyicon.jpg", MAGIC_LEN + 1);
+    memcpy(result, "https://www.flickr.com/images/buddyicon.jpg", MAGIC_LEN + 1);
   }
 
   return result;
@@ -1145,8 +1152,7 @@ flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx,
       memcpy(photo->media_type, "photo", PHOTO_STR_LEN + 1);
     }
 
-    if(xpathNodeCtx)
-      xmlXPathFreeContext(xpathNodeCtx);
+    xmlXPathFreeContext(xpathNodeCtx);
 
     photos[photo_count++] = photo;
   } /* for photos */
@@ -1343,8 +1349,6 @@ flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr,
   memcpy(photos_list->format, nformat, format_len + 1);
 
   tidy:
-  if(xpathNodeCtx)
-    xmlXPathFreeContext(xpathNodeCtx);
   if(xpathObj)
     xmlXPathFreeObject(xpathObj);
   if(xpathCtx)
