@@ -126,11 +126,12 @@ flickcurl_build_photosets(flickcurl* fc, xmlXPathContextPtr xpathCtx,
     ps = (flickcurl_photoset*)calloc(sizeof(flickcurl_photoset), 1);
     
     for(attr = node->properties; attr; attr = attr->next) {
+      size_t attr_len = strlen((const char*)attr->children->content);
       const char *attr_name = (const char*)attr->name;
       char *attr_value;
 
-      attr_value = (char*)malloc(strlen((const char*)attr->children->content)+1);
-      strcpy(attr_value, (const char*)attr->children->content);
+      attr_value = (char*)malloc(attr_len + 1);
+      memcpy(attr_value, attr->children->content, attr_len + 1);
       
       if(!strcmp(attr_name, "id"))
         ps->id = attr_value;
@@ -159,13 +160,15 @@ flickcurl_build_photosets(flickcurl* fc, xmlXPathContextPtr xpathCtx,
       if(chnode->type == XML_ELEMENT_NODE) {
         if(!strcmp(chnode_name, "title")) {
           if(chnode->children) {
-            ps->title = (char*)malloc(strlen((const char*)chnode->children->content)+1);
-            strcpy(ps->title, (const char*)chnode->children->content);
+            size_t len = strlen((const char*)chnode->children->content);
+            ps->title = (char*)malloc(len + 1);
+            memcpy(ps->title, chnode->children->content, len + 1);
           }
         } else if(!strcmp(chnode_name, "description")) {
           if(chnode->children) {
-            ps->description = (char*)malloc(strlen((const char*)chnode->children->content)+1);
-            strcpy(ps->description, (const char*)chnode->children->content);
+            size_t len = strlen((const char*)chnode->children->content);
+            ps->description = (char*)malloc(len + 1);
+            memcpy(ps->description, chnode->children->content, len + 1);
           }
         }
       }
