@@ -506,8 +506,11 @@ flickcurl_serialize_photo(flickcurl_serializer* fcs, flickcurl_photo* photo)
         flickcurl_license* license;
         license = flickcurl_photos_licenses_getInfo_by_id(fc, 
                                                         photo->fields[field].integer);
-        if(!license)
+        if(!license) {
+          if(new_object)
+            free(new_object);
           continue;
+        }
 
         if(license->url) {
           datatype = VALUE_TYPE_URI;
@@ -542,6 +545,7 @@ flickcurl_serialize_photo(flickcurl_serializer* fcs, flickcurl_photo* photo)
           type= FLICKCURL_TERM_TYPE_RESOURCE;
           break;
           
+          /* these value can never been seen; code above never sets it */
         case VALUE_TYPE_NONE:
         case VALUE_TYPE_PHOTO_ID:
         case VALUE_TYPE_PHOTO_URI:
