@@ -129,11 +129,12 @@ flickcurl_build_stats(flickcurl* fc, xmlXPathContextPtr xpathCtx,
     s = (flickcurl_stat*)calloc(sizeof(flickcurl_stat), 1);
     
     for(attr = node->properties; attr; attr = attr->next) {
+      size_t attr_len = strlen((const char*)attr->children->content);
       const char *attr_name = (const char*)attr->name;
       char *attr_value;
 
-      attr_value = (char*)malloc(strlen((const char*)attr->children->content)+1);
-      strcpy(attr_value, (const char*)attr->children->content);
+      attr_value = (char*)malloc(attr_len + 1);
+      memcpy(attr_value, attr->children->content, attr_len + 1);
       
       if(!strcmp(attr_name, "views")) {
         s->views = atoi(attr_value);
@@ -150,6 +151,8 @@ flickcurl_build_stats(flickcurl* fc, xmlXPathContextPtr xpathCtx,
         s->url = attr_value;
       else if(!strcmp(attr_name, "searchterms"))
         s->searchterms = attr_value;
+      else
+        free(attr_value);
     } /* end attributes */
 
 
